##  Prerequisites
  * In SAP LeanIX:
    * Administrator access to your workspace.
    * An API token. You can get it by creating a technical user. For details, see [Technical Users](https://help.sap.com/docs/leanix/ea/technical-users?locale=en-US&state=PRODUCTION&version=CLOUD "To get an API token, create a technical user. Manage technical users collaboratively with other administrators.").
  * Access to your BI tool.
